[][src]Struct raylib::core::drawing::RaylibDrawHandle

pub struct RaylibDrawHandle<'a>(_);

Methods from Deref<Target = RaylibHandle>

pub fn update_camera(&self, camera: &mut Camera3D)[src]

Updates camera position for selected mode.

pub fn is_file_dropped(&self) -> bool[src]

Checks if a file has been dropped into the window.

pub fn get_dropped_files(&self) -> Vec<String>[src]

Gets dropped filenames.

pub fn is_key_pressed(&self, key: KeyboardKey) -> bool[src]

Detect if a key has been pressed once.

pub fn is_key_down(&self, key: KeyboardKey) -> bool[src]

Detect if a key is being pressed.

pub fn is_key_released(&self, key: KeyboardKey) -> bool[src]

Detect if a key has been released once.

pub fn is_key_up(&self, key: KeyboardKey) -> bool[src]

Detect if a key is NOT being pressed.

pub fn is_gamepad_available(&self, gamepad: u32) -> bool[src]

Detect if a gamepad is available.

pub fn is_gamepad_name(&self, gamepad: u32, name: &str) -> bool[src]

Checks gamepad name (if available).

pub fn get_gamepad_name(&self, gamepad: u32) -> Option<String>[src]

Returns gamepad internal name id.

pub fn is_gamepad_button_pressed(
    &self,
    gamepad: u32,
    button: GamepadButton
) -> bool
[src]

Detect if a gamepad button has been pressed once.

pub fn is_gamepad_button_down(
    &self,
    gamepad: u32,
    button: GamepadButton
) -> bool
[src]

Detect if a gamepad button is being pressed.

pub fn is_gamepad_button_released(
    &self,
    gamepad: u32,
    button: GamepadButton
) -> bool
[src]

Detect if a gamepad button has been released once.

pub fn is_gamepad_button_up(&self, gamepad: u32, button: GamepadButton) -> bool[src]

Detect if a gamepad button is NOT being pressed.

pub fn get_gamepad_button_pressed(&self) -> Option<GamepadButton>[src]

Gets the last gamepad button pressed.

pub fn get_gamepad_axis_count(&self, gamepad: u32) -> i32[src]

Returns gamepad axis count for a gamepad.

pub fn get_gamepad_axis_movement(&self, gamepad: u32, axis: u32) -> f32[src]

Returns axis movement value for a gamepad axis.

pub fn is_mouse_button_pressed(&self, button: MouseButton) -> bool[src]

Detect if a mouse button has been pressed once.

pub fn is_mouse_button_down(&self, button: MouseButton) -> bool[src]

Detect if a mouse button is being pressed.

pub fn is_mouse_button_released(&self, button: MouseButton) -> bool[src]

Detect if a mouse button has been released once.

pub fn is_mouse_button_up(&self, button: MouseButton) -> bool[src]

Detect if a mouse button is NOT being pressed.

pub fn get_mouse_x(&self) -> i32[src]

Returns mouse position X.

pub fn get_mouse_y(&self) -> i32[src]

Returns mouse position Y.

pub fn get_mouse_position(&self) -> Vector2[src]

Returns mouse position.

pub fn get_mouse_wheel_move(&self) -> i32[src]

Returns mouse wheel movement Y.

pub fn get_touch_x(&self) -> i32[src]

Returns touch position X for touch point 0 (relative to screen size).

pub fn get_touch_y(&self) -> i32[src]

Returns touch position Y for touch point 0 (relative to screen size).

pub fn get_touch_position(&self, index: u32) -> Vector2[src]

Returns touch position XY for a touch point index (relative to screen size).

pub fn set_gestures_enabled(&self, gesture_flags: u32)[src]

Enables a set of gestures using flags.

pub fn is_gesture_detected(&self, gesture: GestureType) -> bool[src]

Checks if a gesture have been detected.

pub fn get_gesture_detected(&self) -> u32[src]

Gets latest detected gesture.

pub fn get_touch_points_count(&self) -> u32[src]

Gets touch points count.

pub fn get_gesture_hold_duration(&self) -> f32[src]

Gets gesture hold time in milliseconds.

pub fn get_gesture_drag_vector(&self) -> Vector2[src]

Gets gesture drag vector.

pub fn get_gesture_drag_angle(&self) -> f32[src]

Gets gesture drag angle.

pub fn get_gesture_pinch_vector(&self) -> Vector2[src]

Gets gesture pinch delta.

pub fn get_gesture_pinch_angle(&self) -> f32[src]

Gets gesture pinch angle.

pub fn get_matrix_modelview(&self) -> Matrix[src]

Gets internal modelview matrix.

pub fn get_matrix_projection(&self) -> Matrix[src]

Gets internal projection matrix.

pub fn get_font_default(&self) -> WeakFont[src]

Gets the default font.

pub fn get_clipboard_text(&self) -> Result<String, Utf8Error>[src]

Get clipboard text content

pub fn get_mouse_ray(
    &self,
    mouse_position: impl Into<Vector2>,
    camera: impl Into<Camera>
) -> Ray
[src]

Returns a ray trace from mouse position

pub fn get_world_to_screen(
    &self,
    position: impl Into<Vector3>,
    camera: impl Into<Camera>
) -> Vector2
[src]

Returns the screen space position for a 3d world space position

pub fn get_world_to_screen2D(
    &self,
    position: impl Into<Vector2>,
    camera: impl Into<Camera2D>
) -> Vector2
[src]

Returns the screen space position for a 2d camera world space position

pub fn get_world_to_screen_ex(
    &self,
    position: impl Into<Vector3>,
    camera: impl Into<Camera>,
    width: i32,
    height: i32
) -> Vector2
[src]

Returns size position for a 3d world space position

pub fn get_screen_to_world2D(
    &self,
    position: impl Into<Vector2>,
    camera: impl Into<Camera2D>
) -> Vector2
[src]

Returns the world space position for a 2d camera screen space position

pub fn get_fps(&self) -> u32[src]

Returns current FPS

pub fn get_frame_time(&self) -> f32[src]

Returns time in seconds for last frame drawn

pub fn get_time(&self) -> f64[src]

Returns elapsed time in seconds since InitWindow()

pub fn window_should_close(&self) -> bool[src]

Checks if KEY_ESCAPE or Close icon was pressed.

pub fn is_window_ready(&self) -> bool[src]

Checks if window has been initialized successfully.

pub fn is_window_minimized(&self) -> bool[src]

Checks if window has been minimized (or lost focus).

pub fn is_window_resized(&self) -> bool[src]

Checks if window has been resized.

pub fn is_window_hidden(&self) -> bool[src]

Checks if window has been hidden.

pub fn set_window_title(&self, _: &RaylibThread, title: &str)[src]

Sets title for window (only on desktop platforms).

pub fn get_screen_width(&self) -> i32[src]

Gets current screen width.

pub fn get_screen_height(&self) -> i32[src]

Gets current screen height.

pub fn get_window_position(&self) -> Vector2[src]

Get window position

pub fn is_cursor_hidden(&self) -> bool[src]

Checks if mouse cursor is not visible.